#
# spec file for package python3-pynest2d
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python3-pynest2d
Version:        4.12.0
Release:        3.1
Summary:        CPython bindings for libnest2d
License:        LGPL-3.0-only
Group:          Development/Libraries/C and C++
URL:            https://github.com/Ultimaker/pynest2d
Source:         https://github.com/Ultimaker/pynest2d/archive/refs/tags/%{version}.tar.gz#/pynest2d-%{version}.tar.gz
# PATCH-FIX-OPENSUSE -- add PyQt5 namespace
Patch0:         pynest2d-PyQt5.sip.patch
# PATCH-FIX-UPSTREAM -- https://github.com/Ultimaker/pynest2d/pull/3
Patch1:         Retrieve-required-flags-from-Libnest2D-target.patch
BuildRequires:  cmake >= 3.6
BuildRequires:  gcc-c++
BuildRequires:  libnest2d-devel
BuildRequires:  python3-setuptools
BuildRequires:  python3-sip-devel < 5
%if 0%{?suse_version} >= 1550 || 0%{?sle_version} > 150300
# The PyQt5.sip module. NOT a dependency on (Py)Qt5
BuildRequires:  python3-qt5-sip
Requires:       python3-qt5-sip
%else
# Older distributions provide PyQt5.sip through python3-sip
BuildRequires:  python3-sip < 5
Requires:       python3-sip < 5
%endif

%description
Binding allowing libnest2d to be called from Python using Numpy.

%prep
%autosetup -n pynest2d-%{version} -p1

%build
%cmake
%cmake_build

%install
%cmake_install

%files
%license LICENSE
%doc README.md
%{python3_sitearch}/pynest2d.so

%changelog
* Wed Mar 19 2025 Lucas Mulling <lucas.mulling@suse.com>
- Add missing build requirement python3-setuptools
* Wed Mar  9 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Restore Retrieve-required-flags-from-Libnest2D-target.patch,
  which is not upstream, and rebase.
  This fixes building for Leap 15.3 and 15.4.
* Wed Mar  9 2022 Dirk Stoecker <opensuse@dstoecker.de>
- update to 4.12.0 (no changelog provided)
- Drop upstream patch: Retrieve-required-flags-from-Libnest2D-target.patch
- Rebase pynest2d-PyQt5.sip.patch (partially upstreamed)
* Sat Feb 26 2022 Max Lin <mlin@suse.com>
- Use BuildRequires python3-qt5-sip for Leap 15.4
* Sun Nov 22 2020 Benjamin Greiner <code@bnavigator.de>
- Require the PyQt5.sip module (see sr#849990 for libArcus and
  the discussion in gh#Ultimaker/libSavitar#26)
* Sat Nov 21 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Depend on python3-sip < 5, as libSavitar build is incompatible
  with SIP 5 and upstream currently has no intention to update,
  see gh#Ultimaker/libSavitar#26.
* Tue Nov 10 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to final 4.8.0, no code changes
* Sun Oct 25 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Initial package version 4.8~beta
- Add pynest2d-PyQt5.sip.patch
- Add Retrieve-required-flags-from-Libnest2D-target.patch
